module.exports = defineTest({
	description: 'retains arguments that have side-effects'
});
